#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hlint
version:              3.6.1
visibility:           public
id:                   hlint-3.6.1-5NIlrdcfRsZ93TbVY4I17H
key:                  hlint-3.6.1-5NIlrdcfRsZ93TbVY4I17H
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2023
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/hlint#readme
synopsis:             Source code suggestions
description:          HLint gives suggestions on how to improve your source code.
category:             Development
abi:                  90397bbb165c87cc53fd5f4488b76106
exposed:              True
exposed-modules:      Language.Haskell.HLint
hidden-modules:
    Paths_hlint Apply CmdLine Extension Fixity HLint HsColour Idea
    Report Util Parallel Refact Timing CC EmbedData SARIF Summary
    Config.Compute Config.Haskell Config.Read Config.Type Config.Yaml
    GHC.All GHC.Util GHC.Util.ApiAnnotation GHC.Util.View
    GHC.Util.Brackets GHC.Util.DynFlags GHC.Util.FreeVars
    GHC.Util.HsDecl GHC.Util.HsExpr GHC.Util.SrcLoc GHC.Util.Scope
    GHC.Util.Unify Hint.All Hint.Bracket Hint.Comment Hint.Duplicate
    Hint.Export Hint.Extensions Hint.Fixities Hint.Import Hint.Lambda
    Hint.List Hint.ListRec Hint.Match Hint.Monad Hint.Naming
    Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict Hint.Smell
    Hint.Type Hint.Unsafe Hint.NumLiteral Test.All Test.Annotations
    Test.InputOutput Test.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hlint-3.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hlint-3.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hlint-3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hlint
hs-libraries:         HShlint-3.6.1-5NIlrdcfRsZ93TbVY4I17H
depends:
    aeson-2.2.2.0-GDAHVM41MmSECw1rdoDU4M
    ansi-terminal-1.1-B9wXUZLJN9hAlKDPl1kvvR base-4.18.2.1
    bytestring-0.11.5.3 cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    containers-0.6.7 cpphs-1.20.9.1-24V9xcsZlOA6VFsNCn4tMO
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    deriving-aeson-0.2.10-7bxKi7VFUMz9cWV7wqx4vE directory-1.3.8.5
    extra-1.7.16-7Us6XiRrmi4JVcvk4FvIio
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    filepattern-0.1.3-JMKUiy3g9ij9o1GybtwYPp ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-lib-parser-ex-9.6.0.2-JoPELLVkfDOL7Aib9fVHnf
    hscolour-1.25-c2V5rD89ob6QNSiP65exR process-1.6.19.0
    refact-0.3.0.2-FJtsqxURVxtCj2G2lOYVeD text-2.0.2
    transformers-0.6.1.0 uniplate-1.6.13-FXuZ6Au097PIz2azb7agRv
    unordered-containers-0.2.20.1-GdjPUvgItW77rL1YhzClz
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    vector-0.13.2.0-2P3Vv0GFH0i4NgSchvbpWK
    yaml-0.11.11.2-1eTJ7jydtadKIZax7fbx51

haddock-interfaces:   /usr/share/doc/hlint/html/hlint.haddock
haddock-html:         /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

